##  How do I model interface technology?
There are two good ways to model technology for an Interface:
  * As a Tag Group: The advantage is that it can be displayed very prominently on the Interface Fact Sheet.
  * As an IT Component: This allows you to reconcile the Interface with IT Components and display the technology on the Data Flow report.
